@@ -1,4 +1,4 @@
-require 'spec_helper'
+# frozen_string_literal: true
 
 describe WPScan::DB::DynamicFinders::Base do
   subject(:dynamic_finders) { described_class }
