@@ -74,14 +74,14 @@ WPScan::DB::DynamicFinders::Plugin.versions_finders_configs.each do |slug, confi
                 end
 
                 it 'returns the expected version/s' do
-                  found = [*finder.passive]
+                  found = Array(finder.passive)
 
                   expect(found).to_not be_empty
 
                   found.each_with_index do |version, index|
                     expected_version = expected.at(index)
                     expected_ie = expected_version['interesting_entries'].map do |ie|
-                      ie.gsub(target.url + ',', ie_url + ',')
+                      ie.gsub("#{target.url},", "#{ie_url},")
                     end
 
                     expect(version).to be_a WPScan::Model::Version
@@ -104,14 +104,14 @@ WPScan::DB::DynamicFinders::Plugin.versions_finders_configs.each do |slug, confi
                 end
 
                 it 'returns the expected version/s' do
-                  found = [*finder.passive]
+                  found = Array(finder.passive)
 
                   expect(found).to_not be_empty
 
                   found.each_with_index do |version, index|
                     expected_version = expected.at(index)
                     expected_ie = expected_version['interesting_entries'].map do |ie|
-                      ie.gsub(target.url + ',', ie_url + ',')
+                      ie.gsub("#{target.url},", "#{ie_url},")
                     end
 
                     expect(version).to be_a WPScan::Model::Version
@@ -149,7 +149,7 @@ WPScan::DB::DynamicFinders::Plugin.versions_finders_configs.each do |slug, confi
             end
 
             it 'returns the expected version' do
-              found = [*finder.aggressive]
+              found = Array(finder.aggressive)
 
               expect(found).to_not be_empty
 
